@@ -38,6 +38,7 @@ namespace Nepomuk {
 
         class Term;
         class QueryPrivate;
+        class FileQuery;
 
         /**
          * \brief Convinience definition for request property mappings as used in
@@ -125,6 +126,13 @@ namespace Nepomuk {
              */
             bool isFileQuery() const;
 
+            /**
+             * \return A copy of this query which is restricted to files.
+             *
+             * \since 4.6
+             */
+            FileQuery toFileQuery() const;
+
             /**
              * The root term of the query.
              * This can be any type of term.
@@ -172,6 +180,98 @@ namespace Nepomuk {
              */
             void setOffset( int offset );
 
+            /**
+             * %Nepomuk supports scoring the results based on any full text matching
+             * used in the query (full text matching is done via ComparisonTerm with
+             * the ComparisonTerm::Contains comperator) and sorting the results based
+             * on that score.
+             *
+             * By default full text scoring is disabled since it can mean a serious
+             * impact on query performance.
+             *
+             * \sa setFullTextScoringSortOrder(), Result::score()
+             *
+             * \since 4.6
+             */
+            void setFullTextScoringEnabled( bool enabled );
+
+            /**
+             * Set the full text scoring sort order. Ignored if full text scoring is
+             * disabled.
+             *
+             * By default the sort order is Qt::DescendingOrder.
+             *
+             * \sa setFullTextScoringEnabled()
+             *
+             * \since 4.6
+             */
+            void setFullTextScoringSortOrder( Qt::SortOrder order );
+
+            /**
+             * \return \p true if full text scoring has been enabled.
+             *
+             * \sa setFullTextScoringEnabled()
+             *
+             * \since 4.6
+             */
+            bool fullTextScoringEnabled() const;
+
+            /**
+             * \return The full text scoring sort order as set via setFullTextScoringSortOrder()
+             *
+             * \since 4.6
+             */
+            Qt::SortOrder fullTextScoringSortOrder() const;
+
+            /**
+             * A set of flags that influence the result of the query.
+             *
+             * \sa setQueryFlags(), SparqlFlags
+             *
+             * \since 4.6
+             */
+            enum QueryFlag {
+                /**
+                 * No flags set. This is the default.
+                 */
+                NoQueryFlags = 0x0,
+
+                /**
+                 * By default queries that will only return results which are intended for
+                 * the user's eyes. In situations where an application needs to work on
+                 * internal or statistical data this restriction is not desireable.
+                 * This flag disables the restriction and returns the full set of results.
+                 */
+                NoResultRestrictions = 0x1,
+
+                /**
+                 * Disables the return of full text search excerpts for ComparisonTerm::Contains
+                 * terms which are normally reported through Result::excerpt(). It might make sense
+                 * to set this flag in case one has no need for excerpts and does not want to suffer
+                 * the small performance penalty that comes from querying them
+                 */
+                WithoutFullTextExcerpt = 0x2
+            };
+            Q_DECLARE_FLAGS( QueryFlags, QueryFlag )
+
+            /**
+             * Set the query flags to configure this query.
+             *
+             * \sa queryFlags()
+             *
+             * \since 4.6
+             */
+            void setQueryFlags( QueryFlags flags );
+
+            /**
+             * Get the query flags to configure this query.
+             *
+             * \sa setQueryFlags()
+             *
+             * \since 4.6
+             */
+            QueryFlags queryFlags() const;
+
             /**
              * \class RequestProperty query.h Nepomuk/Query/Query
              *
@@ -274,10 +374,8 @@ namespace Nepomuk {
 
                 /**
                  * Create a SPARQL count query which will return the number
-                 * of results rather than the results themselves. Be aware that
-                 * with a count query any requestProperties() will result in a grouping,
-                 * i.e. multiple count values will be returned with respect to the request
-                 * properties.
+                 * of results rather than the results themselves. The resuling query will have
+                 * a single binding called \p 'cnt'.
                  */
                 CreateCountQuery = 0x1,
 
@@ -286,7 +384,15 @@ namespace Nepomuk {
                  * and nie:hasPart at the same time and even if only one of both is
                  * defined.
                  */
-                HandleInverseProperties = 0x2
+                HandleInverseProperties = 0x2,
+
+                /**
+                 * Create a SPARQL ask query which will simply check if a matching result exists.
+                 * Use Soprano::QueryResultIterator::boolValue() to check the result.
+                 *
+                 * \since 4.6
+                 */
+                CreateAskQuery = 0x4
             };
             Q_DECLARE_FLAGS( SparqlFlags, SparqlFlag )
 
@@ -294,8 +400,12 @@ namespace Nepomuk {
              * Convert the query into a SPARQL query which can be used with the
              * Nepomuk query service or directly in Soprano::Model::executeQuery.
              *
+             * It is recommended to use QueryServiceClient instead of creating
+             * the SPARQL query this way.
+             *
              * The resulting query will bind the results to variable \p 'r'. Request
-             * properties will be bound to variables \p 'reqProp1' through \p 'reqPropN'.
+             * properties will be bound to variables \p 'reqProp1' through \p 'reqPropN'
+             * (the only exception is a count query created via the CreateCountQuery flag).
              *
              * If you are looking for a serialization of a Query which can be parsed again
              * use toString() instead.
@@ -365,6 +475,28 @@ namespace Nepomuk {
              */
             bool operator==( const Query& query ) const;
 
+            /**
+             * Comparison operator.
+             *
+             * \return \p true if this query differs from \p query.
+             *
+             * \since 4.6
+             */
+            bool operator!=( const Query& query ) const;
+
+            /**
+             * Optimizes the query without chaning its meaning. This removes
+             * redundant terms such as NegationTerm and OptionalTerm nestings and flattens
+             * AndTerm and OrTerm hierarchies.
+             *
+             * \return An optimized version of this query.
+             *
+             * \since 4.6
+             *
+             * \sa Term::optimized()
+             */
+            Query optimized() const;
+
             /**
              * Encode the Query in a string. Be aware that this does NOT create a SPARQL
              * query. The returned string can be used to serialize queries that can later
@@ -431,16 +563,45 @@ namespace Nepomuk {
         protected:
             /** \cond protected_query_members */
             QSharedDataPointer<QueryPrivate> d;
-
-            friend class QueryParser;
             /** \endcond */
         };
 
+        /**
+         * Logical and operator which combines \p term into the term
+         * of \p query to match both.
+         *
+         * \sa AndTerm
+         *
+         * \since 4.6
+         */
+        NEPOMUKQUERY_EXPORT Query operator&&( const Query& query, const Term& term );
+
+        /**
+         * Logical or operator which combines \p term into the term
+         * of \p query to match either one.
+         *
+         * \sa OrTerm
+         *
+         * \since 4.6
+         */
+        NEPOMUKQUERY_EXPORT Query operator||( const Query& query, const Term& term );
+
+        /**
+         * Logical negation operator which negates the meaning of
+         * a query.
+         *
+         * \sa NegationTerm::negateTerm()
+         *
+         * \since 4.6
+         */
+        NEPOMUKQUERY_EXPORT Query operator!( const Query& query );
+
         NEPOMUKQUERY_EXPORT uint qHash( const Nepomuk::Query::Query& );
     }
 }
 
 Q_DECLARE_OPERATORS_FOR_FLAGS( Nepomuk::Query::Query::SparqlFlags )
+Q_DECLARE_OPERATORS_FOR_FLAGS( Nepomuk::Query::Query::QueryFlags )
 
 NEPOMUKQUERY_EXPORT QDebug operator<<( QDebug, const Nepomuk::Query::Query& );
 
